@@ -267,7 +267,8 @@ void IMDBFetcher::parseSingleTitleResult() {
   // FIXME: maybe remove parentheses here?
   SearchResult* r = new SearchResult(this,
                                      pPos == -1 ? cap1 : cap1.left(pPos),
-                                     pPos == -1 ? QString::null : cap1.mid(pPos));
+                                     pPos == -1 ? QString::null : cap1.mid(pPos),
+                                     QString());
   m_matches.insert(r->uid, m_url);
   emit signalResultFound(r);
 
@@ -398,7 +399,7 @@ void IMDBFetcher::parseTitleBlock(const QString& str_) {
       break;
     }
 
-    SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc);
+    SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc, QString());
     KURL u(m_url, cap1);
     u.setQuery(QString::null);
     m_matches.insert(r->uid, u);
@@ -479,7 +480,7 @@ void IMDBFetcher::parseSingleNameResult() {
     }
 
     // FIXME: maybe remove parentheses here?
-    SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc);
+    SearchResult* r = new SearchResult(this, pPos == -1 ? cap2 : cap2.left(pPos), desc, QString());
     KURL u(m_url, s_anchorTitleRx->cap(1)); // relative URL constructor
     u.setQuery(QString::null);
     m_matches.insert(r->uid, u);
@@ -715,10 +716,8 @@ void IMDBFetcher::doTitle(const QString& str_, Data::EntryPtr entry_) {
 
 void IMDBFetcher::doRunningTime(const QString& str_, Data::EntryPtr entry_) {
   // running time
-  // this minimal thing makes regexps hard
-  // "runtime:.*(\\d+)" matches to the end of the document if not minimal
-  // and only grabs one digit if minimal
-  QRegExp runtimeRx(QString::fromLatin1("runtime:[^\\d]*(\\d+)"), false);
+  QRegExp runtimeRx(QString::fromLatin1("runtime:.*(\\d+)\\s+min"), false);
+  runtimeRx.setMinimal(true);
 
   if(runtimeRx.search(str_) > -1) {
 //    myDebug() << "running-time = " << runtimeRx.cap(1) << endl;
@@ -733,7 +732,7 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Data::EntryPtr entry_) {
 
   // match until next b tag
 //  QRegExp akaRx(QString::fromLatin1("also known as(.*)<b(?:\\s.*)?>"));
-  QRegExp akaRx(QString::fromLatin1("also known as(.*)<b[>\\s/]"), false);
+  QRegExp akaRx(QString::fromLatin1("also known as(.*)<(b[>\\s/]|div)"), false);
   akaRx.setMinimal(true);
 
   if(akaRx.search(str_) > -1 && !akaRx.cap(1).isEmpty()) {
@@ -757,9 +756,12 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Data::EntryPtr entry_) {
       s.remove(*s_tagRx);
       s.remove(brackRx);
       s = s.stripWhiteSpace();
-      // the first value ends up being the colon after "Also know as"
+      // the first value ends up being or starting with the colon after "Also know as"
       // I'm too lazy to figure out a better regexp
-      if(!s.isEmpty() && s != Latin1Literal(":")) {
+      if(s.startsWith(QChar(':'))) {
+        s = s.mid(1);
+      }
+      if(!s.isEmpty()) {
         values += s;
       }
     }
@@ -928,7 +930,7 @@ void IMDBFetcher::doRating(const QString& str_, Data::EntryPtr entry_) {
     bool ok;
     float value = rx.cap(1).toFloat(&ok);
     if(ok) {
-      entry_->setField(QString::fromLatin1("imdb-rating"), QString::number((int)value));
+      entry_->setField(QString::fromLatin1("imdb-rating"), QString::number(value));
     }
   }
 }
