@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -80,6 +80,7 @@ public slots:
 
 protected slots:
   void slotEditRegExp();
+  void slotRuleFieldChanged(int which);
   void slotRuleFunctionChanged(int which);
 
 private:
@@ -102,7 +103,7 @@ public:
   FilterRuleWidgetLister(QWidget* parent, const char* name=0);
 
   const QPtrList<QWidget>& widgetList() const;
-  void setFilter(const Filter* filter);
+  void setFilter(Filter::Ptr filter);
 
 public slots:
   void reset();
@@ -136,8 +137,8 @@ public:
    */
   FilterDialog(Mode mode, QWidget* parent, const char* name=0);
 
-  Filter* currentFilter();
-  void setFilter(Filter* filter);
+  FilterPtr currentFilter();
+  void setFilter(FilterPtr filter);
 
 public slots:
   void slotClear();
@@ -150,7 +151,7 @@ protected slots:
   void slotSaveFilter();
 
 signals:
-  void signalUpdateFilter(Tellico::Filter*);
+  void signalUpdateFilter(Tellico::FilterPtr);
   void signalCollectionModified();
 
 private:
