@@ -46,8 +46,9 @@ LineFieldWidget::LineFieldWidget(Data::FieldPtr field_, QWidget* parent_, const
 
 QString LineFieldWidget::text() const {
   QString text = m_lineEdit->text();
-  text.replace(s_semiColon, QString::fromLatin1("; "));
-  text.replace(s_comma, QString::fromLatin1(", "));
+  if(field()->flags() & Data::Field::AllowMultiple) {
+    text.replace(s_semiColon, QString::fromLatin1("; "));
+  }
   return text.stripWhiteSpace();
 }
 
