@@ -17,6 +17,7 @@
 #include "attrib.h"
 #include "lex_auxiliary.h"
 #include "error.h"
+#include "parse_auxiliary.h"
 /*#include "my_dmalloc.h"*/
 
 extern char * InputFilename;            /* for zzcr_ast call in pccts/ast.c */
@@ -35,6 +36,9 @@ extern char * InputFilename;            /* for zzcr_ast call in pccts/ast.c */
 #include "ast.c"
 zzASTgvars
 
+static void value(AST**_root);
+static void field(AST**_root);
+
 ANTLR_INFO
 
 void
@@ -44,13 +48,13 @@ bibfile(AST**_root)
 	zzBLOCK(zztasp1);
 	zzMake0;
 	{
-	AST *last; (*_root) = NULL;   
+	AST *last; (*_root) = NULL;
 	{
 		zzBLOCK(zztasp2);
 		zzMake0;
 		{
 		while ( (LA(1)==AT) ) {
-			_ast = NULL; entry(&_ast);
+			_ast = NULL; bibentry(&_ast);
 			/* a little creative forestry... */
 			if ((*_root) == NULL)
 			(*_root) = zzastArg(1);
@@ -72,16 +76,16 @@ fail:
 }
 
 void
-entry(AST**_root)
+bibentry(AST**_root)
 {
 	zzRULE;
 	zzBLOCK(zztasp1);
 	zzMake0;
 	{
-	bt_metatype metatype;   
+	bt_metatype metatype;
 	zzmatch(AT);  zzCONSUME;
 	zzmatch(NAME); zzsubroot(_root, &_sibling, &_tail);
-	
+
 	metatype = entry_metatype();
 	zzastArg(1)->nodetype = BTAST_ENTRY;
 	zzastArg(1)->metatype = metatype;
@@ -107,7 +111,7 @@ body(AST**_root, bt_metatype metatype )
 	if ( (LA(1)==STRING) ) {
 		if (!(metatype == BTE_COMMENT )) {zzfailed_pred("   metatype == BTE_COMMENT ");}
 		zzmatch(STRING); zzsubchild(_root, &_sibling, &_tail);
-		zzastArg(1)->nodetype = BTAST_STRING;   
+		zzastArg(1)->nodetype = BTAST_STRING;
  zzCONSUME;
 
 	}
@@ -153,7 +157,7 @@ contents(AST**_root, bt_metatype metatype )
 			zzEXIT(zztasp2);
 			}
 		}
-		zzastArg(1)->nodetype = BTAST_KEY;   
+		zzastArg(1)->nodetype = BTAST_KEY;
 		zzmatch(COMMA);  zzCONSUME;
 		fields(zzSTR); zzlink(_root, &_sibling, &_tail);
 	}
@@ -214,7 +218,7 @@ fail:
 	}
 }
 
-void
+static void
 field(AST**_root)
 {
 	zzRULE;
@@ -222,12 +226,12 @@ field(AST**_root)
 	zzMake0;
 	{
 	zzmatch(NAME); zzsubroot(_root, &_sibling, &_tail);
-	zzastArg(1)->nodetype = BTAST_FIELD; check_field_name (zzastArg(1));   
+	zzastArg(1)->nodetype = BTAST_FIELD; check_field_name (zzastArg(1));
  zzCONSUME;
 
 	zzmatch(EQUALS);  zzCONSUME;
 	value(zzSTR); zzlink(_root, &_sibling, &_tail);
-	
+
 #if DEBUG > 1
 	printf ("field: fieldname = %p (%s)\n"
 	"       first val = %p (%s)\n",
@@ -242,7 +246,7 @@ fail:
 	}
 }
 
-void
+static void
 value(AST**_root)
 {
 	zzRULE;
@@ -280,21 +284,21 @@ simple_value(AST**_root)
 	{
 	if ( (LA(1)==STRING) ) {
 		zzmatch(STRING); zzsubchild(_root, &_sibling, &_tail);
-		zzastArg(1)->nodetype = BTAST_STRING;   
+		zzastArg(1)->nodetype = BTAST_STRING;
  zzCONSUME;
 
 	}
 	else {
 		if ( (LA(1)==NUMBER) ) {
 			zzmatch(NUMBER); zzsubchild(_root, &_sibling, &_tail);
-			zzastArg(1)->nodetype = BTAST_NUMBER;   
+			zzastArg(1)->nodetype = BTAST_NUMBER;
  zzCONSUME;
 
 		}
 		else {
 			if ( (LA(1)==NAME) ) {
 				zzmatch(NAME); zzsubchild(_root, &_sibling, &_tail);
-				zzastArg(1)->nodetype = BTAST_MACRO;   
+				zzastArg(1)->nodetype = BTAST_MACRO;
  zzCONSUME;
 
 			}
