@@ -169,7 +169,7 @@ Tellico::Data::CollPtr FileListingImporter::collection() {
       }
     }
 
-    m_coll->addEntry(entry);
+    m_coll->addEntries(entry);
 
     if(j%stepSize == 0) {
       ProgressManager::self()->setProgress(this, j);
@@ -182,7 +182,6 @@ Tellico::Data::CollPtr FileListingImporter::collection() {
     return 0;
   }
 
-  m_coll->updateDicts(m_coll->entries());
   return m_coll;
 }
 
